package com.jiuqi.util;

import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.text.DecimalFormat;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/Format.class */
public class Format {
    public static char fillChar = ' ';
    private static final String EOL = System.getProperty("line.separator");
    private static PrintWriter handle = new PrintWriter(new OutputStreamWriter(System.out));
    private static char alignment;
    private static boolean separator;
    private static char base;
    private static boolean scientific;
    private static boolean zeroFill;
    private static int width;
    private static int decimals;
    private static String pattern;

    private Format() {
    }

    public static String format(byte value, String fd) {
        return formatInteger(value, fd, 8);
    }

    public static String format(char value, String fd) {
        return formatInteger(value, fd, 16);
    }

    public static String format(double value, String fd) {
        String s1;
        extractAttributes(fd);
        if (base == 'B') {
            String s12 = Long.toBinaryString(Double.doubleToLongBits(value));
            String s13 = String.valueOf(repeat(64, '0')) + s12;
            s1 = s13.substring(s13.length() - 64);
        } else if (base == 'X') {
            String s14 = Long.toHexString(Double.doubleToLongBits(value));
            String s15 = String.valueOf(repeat(16, '0')) + s14;
            s1 = s15.substring(s15.length() - 16);
        } else {
            pattern = decimals != -1 ? "." + repeat(decimals, '0') : ".#";
            if (scientific) {
                pattern = JqLib.SQL_FALSE + pattern + "E0";
            } else {
                pattern = separator ? "#,##0" + pattern : JqLib.SQL_FALSE + pattern;
            }
            s1 = new DecimalFormat(pattern).format(value);
        }
        return size(s1);
    }

    public static String format(float value, String fd) {
        String s1;
        extractAttributes(fd);
        if (base == 'B') {
            String s12 = Integer.toBinaryString(Float.floatToIntBits(value));
            String s13 = String.valueOf(repeat(32, '0')) + s12;
            s1 = s13.substring(s13.length() - 32);
        } else if (base == 'X') {
            String s14 = Integer.toHexString(Float.floatToIntBits(value));
            String s15 = String.valueOf(repeat(8, '0')) + s14;
            s1 = s15.substring(s15.length() - 8);
        } else {
            pattern = decimals != -1 ? "." + repeat(decimals, '0') : ".#";
            if (scientific) {
                pattern = JqLib.SQL_FALSE + pattern + "E0";
            } else {
                pattern = separator ? "#,##0" + pattern : JqLib.SQL_FALSE + pattern;
            }
            s1 = new DecimalFormat(pattern).format(value);
        }
        return size(s1);
    }

    public static String format(int value, String fd) {
        return formatInteger(value, fd, 32);
    }

    public static String format(long value, String fd) {
        return formatInteger(value, fd, 64);
    }

    public static String format(short value, String fd) {
        return formatInteger(value, fd, 16);
    }

    private static String formatInteger(long l, String s, int i) {
        String s1;
        extractAttributes(s);
        if (base == 'B') {
            String s12 = String.valueOf(repeat(64, '0')) + Long.toBinaryString(l);
            s1 = s12.substring(s12.length() - i);
        } else if (base == 'X') {
            String s13 = String.valueOf(repeat(16, '0')) + Long.toHexString(l);
            s1 = s13.substring(s13.length() - (i / 4));
        } else if (separator) {
            s1 = new DecimalFormat("#,###").format(l);
        } else {
            s1 = String.valueOf(l);
            if (zeroFill) {
                s1 = String.valueOf(repeat(width - s1.length(), '0')) + s1;
            }
        }
        return size(s1);
    }

    private static void extractAttributes(String s) {
        String s2 = s.toUpperCase();
        alignment = 'R';
        separator = false;
        base = 'D';
        scientific = false;
        zeroFill = false;
        width = -1;
        decimals = -1;
        int i = s2.indexOf(76, 0);
        if (i > -1) {
            alignment = 'L';
            s2 = String.valueOf(s2.substring(0, i)) + s2.substring(i + 1);
        }
        int i2 = s2.indexOf(67, 0);
        if (i2 > -1) {
            alignment = 'C';
            s2 = String.valueOf(s2.substring(0, i2)) + s2.substring(i2 + 1);
        }
        int i3 = s2.indexOf(44, 0);
        if (i3 > -1) {
            separator = true;
            pattern = String.valueOf(pattern) + ",###";
            s2 = String.valueOf(s2.substring(0, i3)) + s2.substring(i3 + 1);
        }
        int i4 = s2.indexOf(88, 0);
        if (i4 > -1) {
            base = 'X';
            s2 = String.valueOf(s2.substring(0, i4)) + s2.substring(i4 + 1);
        } else {
            int i5 = s2.indexOf(66, 0);
            if (i5 > -1) {
                base = 'B';
                s2 = String.valueOf(s2.substring(0, i5)) + s2.substring(i5 + 1);
            }
        }
        int i6 = s2.indexOf(83, 0);
        if (i6 > -1) {
            scientific = true;
            s2 = String.valueOf(s2.substring(0, i6)) + s2.substring(i6 + 1);
        }
        int i7 = s2.indexOf(90, 0);
        if (i7 > -1) {
            zeroFill = true;
            s2 = String.valueOf(s2.substring(0, i7)) + s2.substring(i7 + 1);
        }
        int i8 = s2.indexOf(46, 0);
        if (i8 > -1) {
            decimals = Integer.parseInt(s2.substring(i8 + 1));
            s2 = s2.substring(0, i8);
        }
        if (s2.length() > 0) {
            width = Integer.parseInt(s2);
        }
    }

    public static void print(byte value, String fd) {
        handle.print(format(value, fd));
        handle.flush();
    }

    public static void print(char value, String fd) {
        handle.print(format(value, fd));
        handle.flush();
    }

    public static void print(double value, String fd) {
        handle.print(format(value, fd));
        handle.flush();
    }

    public static void print(float value, String fd) {
        handle.print(format(value, fd));
        handle.flush();
    }

    public static void print(int value, String fd) {
        handle.print(format(value, fd));
        handle.flush();
    }

    public static void print(long value, String fd) {
        handle.print(format(value, fd));
        handle.flush();
    }

    public static void print(short value, String fd) {
        handle.print(format(value, fd));
        handle.flush();
    }

    public static void println(byte value, String fd) {
        print(value, fd);
        handle.print(EOL);
        handle.flush();
    }

    public static void println(char value, String fd) {
        print(value, fd);
        handle.print(EOL);
        handle.flush();
    }

    public static void println(double value, String fd) {
        print(value, fd);
        handle.print(EOL);
        handle.flush();
    }

    public static void println(float value, String fd) {
        print(value, fd);
        handle.print(EOL);
        handle.flush();
    }

    public static void println(int value, String fd) {
        print(value, fd);
        handle.print(EOL);
        handle.flush();
    }

    public static void println(long value, String fd) {
        print(value, fd);
        handle.print(EOL);
        handle.flush();
    }

    public static void println(short value, String fd) {
        print(value, fd);
        handle.print(EOL);
        handle.flush();
    }

    private static String size(String s) {
        int i = width - s.length();
        if (alignment == 'R') {
            return String.valueOf(repeat(i, fillChar)) + s;
        }
        if (alignment == 'L') {
            return String.valueOf(s) + repeat(i, fillChar);
        }
        return String.valueOf(repeat(i / 2, fillChar)) + s + repeat((i / 2) + (i % 2), fillChar);
    }

    public static String repeat(int times, char c) {
        String s = "";
        for (int i = 0; i < times; i++) {
            s = String.valueOf(s) + c;
        }
        return s;
    }
}
